#!/bin/bash
# Temp iwx backups script.  Add to root crontab at prefered time.  Packaged compressed, local backups only at this time.  Although you could use something like NFS to make the backups remote.

# Feature Backlog :
# incremental backup
# Custom pre and post backup scripts.
# FTP
# S3

# How many Daily copies to keep.
# Daily Backups are currently Needed for this Script
DC=$1
# How many Weekly copies to keep. 0 is disabled.
WC=$2
# How many Monthly copies to keep. 0 is disabled.
MC=$3

#Backup dir
BKDIR=$4
ADMIN_EMAIL="$(nodeworx -u -n --controller Users --action listMasterUser | grep email | awk '{print $2}')"

DIR="$(dirname "${BASH_SOURCE[0]}")"

source "$DIR"/iwx-backup.conf

date=`date +'%Y%m%d'`

#Check disk usage
"$DIR"/iwx-backup-diskusage.sh $4 $5 
[ $? -eq 1 ] && exit 1

function daily {
    # Ensure Daily Folder Exists
    mkdir $BKDIR/daily/

    # Check if Daily Backups are Enabled
    if [ $DC -gt "0" ]
    then
        # Ensure Backup Retention is kept
        while [ $(\ls -p $BKDIR/daily/ | grep '^Daily_[0-9]\{8\}/$' | wc -l) -ge $DC ]
            do ionice -c3 rm -rf $BKDIR/daily/Daily$(\ls -p $BKDIR/daily/ | grep 'Daily_[0-9]\{8\}/$' | head -n1 | sed 's/.*_/_/')
        done

        # Create New Backup's Folder
        mkdir $BKDIR/daily/Daily_$date
        # Create New Backup
        [[ -d /home/iwbktmp ]] || mkdir -p /home/iwbktmp
        /home/interworx/bin/backup.pex --backup-options all --domains all --tmp-dir /home/iwbktmp --output-dir $BKDIR/daily/Daily_$date/ --email $ADMIN_EMAIL > $BKDIR/daily/Daily_$date/backup.log
    fi
}

function weekly {
    # Ensure Weekly Folder Exists
    mkdir $BKDIR/weekly/

    # Check if Weekly Backups are Enabled
    if [ $WC -gt "0" ]
    then
        # Check if the current day is a Weekly Backup Day
        if [ $(date '+%u') -eq $DAY_WEEKLY ]
        then
            # Cleanup all old Weekly backups over the set Weekly Count and create weekly snapshot.
            while [ $(\ls -p $BKDIR/weekly/ | grep '^Weekly_[0-9]\{8\}/$' | wc -l) -ge $WC ]
                do ionice -c3 rm -rf $BKDIR/weekly/Weekly$(\ls -p $BKDIR/weekly/ | grep 'Weekly_[0-9]\{8\}/$' | head -n1 | sed 's/.*_/_/')
            done

            # Copy Daily backup to the Weekly Folder
            ionice -c3 rsync -aH --delete --link-dest=$BKDIR/daily/Daily_$date/ $BKDIR/daily/Daily_$date/ $BKDIR/weekly/Weekly_$date/

        fi
    fi
}

function monthly {
    # Ensure Monthly Folder Exists
    mkdir $BKDIR/monthly/

    # Check if Monthly disabled
    if [ $MC -gt "0" ]
    then
        # Check if the current day is a Monthly Backup Day
        if [ $(date '+%d') -eq $DAY_MONTHLY ]
        then
            # Cleanup all old Monthly backups over the set Monthly Count and create Monthly snapshot.
            while [ $(\ls -p $BKDIR/monthly/ | grep '^Monthly_[0-9]\{8\}/$' | wc -l) -ge $MC ]
                do ionice -c3 rm -rf $BKDIR/monthly/Monthly$(\ls -p $BKDIR/monthly/ | grep 'Monthly_[0-9]\{8\}/$' | head -n1 | sed 's/.*_/_/')
            done

            # Copy Daily backup to the Monthly Folder
            ionice -c3 rsync -aH --delete --link-dest=$BKDIR/daily/Daily_$date/ $BKDIR/daily/Daily_$date/ $BKDIR/monthly/Monthly_$date/

        fi
    fi
}

daily
weekly
monthly
